@@ -251,12 +251,17 @@ void open_dir(GtkTreeView * treeview, GtkTreeIter * iter, GtkTreePath * treepath
 	    }
 	    goto time2return;
 	}
-	if (en->tag && strchr(en->tag,'%'))
-		print_status_tmp(treeview, resolve_icon_small(en),
-			       	FILENAME(en), NULL);
-	else
+	if (en->tag && strchr(en->tag,'%')){
+	      char *p=g_strdup(en->tag);
+	      p=strtok(p,"%");
+	      print_status_tmp(treeview, resolve_icon_small(en),p, NULL);
+	      g_free(p);
+	}
+	else if (en->tag)
 		print_status_tmp(treeview, resolve_icon_small(en),
 			       	en->tag, NULL);
+	else print_status_tmp(treeview, resolve_icon_small(en),
+			       	"", NULL);
 	/*set_select_path(treemodel,iter,tree_details); */
 	/* when expand icon is different: set_icon(treeview,iter); */
 
@@ -333,12 +338,16 @@ void open_dir(GtkTreeView * treeview, GtkTreeIter * iter, GtkTreePath * treepath
 	set_icon(treeview, iter);
 
 	    /*printf("DBG: tag writing %s\n",en->path);*/
-	if (en->tag && strchr(en->tag,'%'))
-		print_status_tmp(treeview, resolve_icon_small(en),
-			       	FILENAME(en), NULL);
-	else
+	if (en->tag && strchr(en->tag,'%')){
+	      char *p=g_strdup(en->tag);
+	      p=strtok(p,"%");
+	      print_status_tmp(treeview, resolve_icon_small(en),p, NULL);
+	      g_free(p);
+	}
+	else if(en->tag)
 		print_status_tmp(treeview, resolve_icon_small(en),
 			       	en->tag, NULL);
+	else print_status_tmp(treeview, resolve_icon_small(en),"",NULL);
 
     }
   time2return:
@@ -503,7 +512,15 @@ void close_dir(GtkTreeView * treeview, GtkTreeIter * iter, GtkTreePath * path, g
     	    if (title_reference) gtk_tree_row_reference_free(title_reference);
        	    title_reference = gtk_tree_row_reference_new(treemodel, tpath);
 	    /*FIXME This might segv on race condition: */
-	    print_status(treeview, resolve_folder_icon(p_en), p_en->tag, NULL);
+	    if (p_en && p_en->tag && strchr(p_en->tag,'%')) {
+	      char *p=g_strdup(p_en->tag);
+	      p=strtok(p,"%");
+	      print_status_tmp(treeview, resolve_icon_small(p_en),p, NULL);
+	      g_free(p);
+	    }
+	    else if (p_en && p_en->tag)
+	      print_status(treeview, resolve_folder_icon(p_en), p_en->tag, NULL);
+	    else print_status(treeview, resolve_folder_icon(p_en),"", NULL);
 	    set_path_reference(treeview,tpath);
 	    gtk_tree_path_free(tpath);
 	}
@@ -513,8 +530,16 @@ void close_dir(GtkTreeView * treeview, GtkTreeIter * iter, GtkTreePath * path, g
 	    *window_title=g_strdup(en->path);
     	    if (title_reference) gtk_tree_row_reference_free(title_reference);
        	    title_reference = gtk_tree_row_reference_new(treemodel, path);
-	    print_status(treeview, resolve_folder_icon(en), en->tag, NULL);
-	}
+	    if (en && en->tag && strchr(en->tag,'%')) {
+	      char *p=g_strdup(en->tag);
+	      p=strtok(p,"%");
+	      print_status_tmp(treeview, resolve_icon_small(en),p, NULL);
+	      g_free(p);
+	    } else if (en->tag)
+		print_status_tmp(treeview, resolve_icon_small(en),en->tag, NULL);
+	    else print_status_tmp(treeview, resolve_icon_small(en),"", NULL);
+
+}
 	set_title(treeview,window_title);
     }
   time2return:
@@ -581,22 +606,23 @@ gboolean button_releaseF(GtkWidget * widget, GdkEventButton * event, gpointer da
 	    if(gtk_tree_view_get_path_at_pos(treeview, event->x, event->y, 
 				    &treepath, NULL, NULL, NULL))
 	    {
-		gchar *readable_path;
 		gtk_tree_model_get_iter(treemodel, &iter, treepath);
-
 		gtk_tree_model_get(treemodel, &iter, ENTRY_COLUMN, &en, -1);
-		readable_path=g_path_get_basename(en->path);
-		if (IS_NETWORK_TYPE(en->type)&&!IS_SAMBA_SERVER(en->subtype))
+		if (!en || !en->path){
+			print_status_tmp(treeview, resolve_icon_small(en), "",NULL);
+	        } else {
+		  gchar *readable_path=g_path_get_basename(en->path);
+		  if (IS_NETWORK_TYPE(en->type)&&!IS_SAMBA_SERVER(en->subtype))
 			ascii_readable(readable_path);
-		print_status_tmp(treeview, resolve_icon_small(en), 
+		  print_status_tmp(treeview, resolve_icon_small(en), 
 				readable_path,
 				NULL);
-		g_free(readable_path);
-		readable_path=NULL;
-		set_path_reference(treeview,treepath);
+		  g_free(readable_path);
+		  set_path_reference(treeview,treepath);
+		}
 		
-		gtk_tree_path_free(treepath);
-		turn_on(treeview);
+	        gtk_tree_path_free(treepath);
+	        turn_on(treeview);
 	    }
 	    clear_dnd_selection_list();
 	    break;
